@@ -164,16 +164,16 @@ is then associated with the match."
 (defcustom lui-buttons-list
   `(("`\\([A-Za-z0-9+=*/-]+\\)'" 1
      lui-button-elisp-symbol 1)
-    ("debbugs#\\([0-9]+\\)" 0
+    ("\\<debbugs[#:]\\([0-9]+\\)" 0
      "https://debbugs.gnu.org/cgi/bugreport.cgi?bug=%s" 1)
-    ("RFC ?\\([0-9]+\\)" 0
+    ("\\<RFC ?\\([0-9]+\\)" 0
      "http://www.ietf.org/rfc/rfc%s.txt" 1)
-    ("CVE[- ]\\([0-9]+-[0-9]+\\)" 0
+    ("\\<CVE[- ]\\([0-9]+-[0-9]+\\)" 0
      "https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-%s" 1)
-    ("SRFI[- ]?\\([0-9]+\\)" 0
+    ("\\<SRFI[- ]?\\([0-9]+\\)" 0
      "http://srfi.schemers.org/srfi-%s/srfi-%s.html" 1 1)
-    ("PEP[- ]?\\([0-9]+\\)" 0 lui-button-pep 1)
-    ("xkcd[ #]*\\([0-9]+\\)" 0
+    ("\\<PEP[- ]?\\([0-9]+\\)" 0 lui-button-pep 1)
+    ("\\<xkcd[ #]*\\([0-9]+\\)" 0
      "https://xkcd.com/%s" 1)
     ("\\([0-9a-zA-Z_.-]+/[0-9a-zA-Z_.-]+\\)#\\([0-9]+\\)" 0
      "https://github.com/%s/issues/%s" 1 2))
@@ -515,10 +515,10 @@ See `lui-scroll-behavior' for how to customize this."
 
 (defun lui-send-input ()
   "Send the current input to the Lui application.
-If point is not in the input area, self-insert."
+If point is not in the input area, insert a newline."
   (interactive)
   (if (< (point) lui-input-marker)
-      (self-insert-command 1)
+      (newline)
     (save-restriction
       (narrow-to-region lui-input-marker (point-max))
       (run-hooks 'lui-pre-input-hook))
@@ -541,13 +541,14 @@ If point is not in the input area, self-insert."
 
 (define-button-type 'lui-button
   'supertype 'button
+  'follow-link t
   'face 'lui-button-face)
 
 (defun lui-buttonize ()
   "Buttonize the current message."
+  (lui-buttonize-urls)
   (lui-buttonize-custom)
-  (lui-buttonize-issues)
-  (lui-buttonize-urls))
+  (lui-buttonize-issues))
 
 (defun lui-buttonize-custom ()
   "Add custom buttons to the current message.
@@ -560,36 +561,40 @@ This uses `lui-buttons-list'."
           (arg-matches (nthcdr 3 entry)))
       (goto-char (point-min))
       (while (re-search-forward regex nil t)
-        (let* ((function (if (functionp function-or-url)
-                             function-or-url
-                           'browse-url))
-               (matches (mapcar (lambda (n)
-                                  (match-string-no-properties n))
-                                arg-matches))
-               (arguments (if (functionp function-or-url)
-                              matches
-                            (list (apply #'format function-or-url
-                                         matches)))))
-          (make-button (match-beginning submatch)
-                       (match-end submatch)
-                       'type 'lui-button
-                       'action 'lui-button-activate
-                       'lui-button-function function
-                       'lui-button-arguments arguments))))))
+        ;; Ensure we're not inserting a button inside a URL button
+        (when (not (button-at (point)))
+          (let* ((function (if (functionp function-or-url)
+                               function-or-url
+                             'browse-url))
+                 (matches (mapcar (lambda (n)
+                                    (match-string-no-properties n))
+                                  arg-matches))
+                 (arguments (if (functionp function-or-url)
+                                matches
+                              (list (apply #'format function-or-url
+                                           matches)))))
+            (make-button (match-beginning submatch)
+                         (match-end submatch)
+                         'type 'lui-button
+                         'action 'lui-button-activate
+                         'lui-button-function function
+                         'lui-button-arguments arguments)))))))
 
 (defun lui-buttonize-issues ()
   "Buttonize issue references in the current message, if configured."
   (when lui-button-issue-tracker
     (goto-char (point-min))
     (while (re-search-forward "\\(?:^\\|\\W\\)\\(#\\([0-9]+\\)\\)" nil t)
-      (make-button (match-beginning 1)
-                   (match-end 1)
-                   'type 'lui-button
-                   'action 'lui-button-activate
-                   'lui-button-function 'browse-url
-                   'lui-button-arguments
-                   (list (format lui-button-issue-tracker
-                                 (match-string 2)))))))
+      ;; Ensure we're not inserting a button inside a URL button
+      (when (not (button-at (point)))
+        (make-button (match-beginning 1)
+                     (match-end 1)
+                     'type 'lui-button
+                     'action 'lui-button-activate
+                     'lui-button-function 'browse-url
+                     'lui-button-arguments
+                     (list (format lui-button-issue-tracker
+                                   (match-string 2))))))))
 
 (defun lui-buttonize-urls ()
   "Buttonize URLs in the current message."
